import { useRouter } from 'vue-router'
import { useStore } from 'vuex'
import { ref, reactive } from 'vue'
import { logout, updatepassword } from "@/api/manager"
import { removeToken } from "@/composables/auth"
import { showModal, toast } from "@/composables/util"



export function useRepassword() {
    const store = useStore()
    const router = useRouter()
    // 修改密码
    const form = reactive({
        oldpassword: "",
        password: "",
        repassword: ""
    })

    const rules = {
        oldpassword: [
            {
                required: true,
                message: '旧密码不能为空',
                trigger: 'blur'
            },
        ],
        password: [
            {
                required: true,
                message: '新密码不能为空',
                trigger: 'blur'
            },
        ],
        repassword: [
            {
                required: true,
                message: '确认密码不能为空',
                trigger: 'blur'
            },
        ]

    }

    const formRef = ref(null)
    const formDrawerRef = ref(null)

    const onSubmit = () => {
        formRef.value.validate((valid) => {
            if (!valid) {
                return false
            }
            formDrawerRef.value.showLoading();

            updatepassword(form)
                .then(res => {
                    toast("修改密码成功, 请重新登录!")
                    store.dispatch("logout")
                    router.push("/login")

                })
                .finally(() => {
                    formDrawerRef.value.hideLoading();
                })
        })
    }
    const openRePasswordForm = () => formDrawerRef.value.open()
    return {
        formDrawerRef,
        form,
        rules,
        formRef,
        onSubmit,
        openRePasswordForm

    }
}


export function useLogout() {
    const store = useStore()
    const router = useRouter()
    // 退出登录
    function handleLogout() {
        showModal("是否要退出登录?").then(res => {
            console.log("退出登录")
            logout().finally(() => {
                // 移除cookie
                removeToken()

                // 清除当前用户状态 vuex
                store.dispatch("logout")

                // 跳转回登录页
                router.push("/login")

                // 提示退出成功
                toast("退出成功!")
            })
        })
    }

    return {
        handleLogout
    }
}